complete -c sic -n "__fish_use_subcommand" -s i -l input -d 'Input image path. When using this option, input piped from stdin will be ignored. If using unexpanded globs as argument, use --glob-input instead.'
complete -c sic -n "__fish_use_subcommand" -l glob-input -d 'Input glob path which attempts to match all files matching the given glob pattern. Use with --glob-output. Depending on your shell you may need to add explicit quotation marks around the argument.'
complete -c sic -n "__fish_use_subcommand" -s o -l output -d 'Output image path. When using this option, output won\'t be piped to stdout.'
complete -c sic -n "__fish_use_subcommand" -l glob-output -d 'This output should point to a folder in which the greatest root common directory of the glob input will be mirrored'
complete -c sic -n "__fish_use_subcommand" -l select-frame -d 'Frame to be loaded as still image if the input image is an animated image.To pick the first and last frame respectively, you can provide \'first\' and \'last\' as arguments. Otherwise provide a single zero-indexed positive number which corresponds with the frame index. For example, to select the first frame, the argument would be \'0\', for the second \'1\', etc.'
complete -c sic -n "__fish_use_subcommand" -s f -l output-format -d 'Force the output image format to use FORMAT, regardless of the (if any) extension of the given output file path. Output formats (FORMAT values) supported: AVIF, BMP, Farbfeld, GIF, ICO, JPEG, PNG, PAM, PBM, PGM, PPM and TGA.'
complete -c sic -n "__fish_use_subcommand" -l jpeg-encoding-quality -d 'Set the jpeg quality to QUALITY. Valid values are positive numbers from 1 up to and including 100. Will only be used when the output format is determined to be jpeg.'
complete -c sic -n "__fish_use_subcommand" -l gif-repeat -d 'Repeat the frames of a (to be) gif encoded image `n` times, `infinite` times or `never`.'
complete -c sic -n "__fish_use_subcommand" -s x -l apply-operations -d 'Images may be manipulated by performing image operations.
You can instruct sic to perform image operations by means of the image script or by specifying image operations directly
through the CLI interface.

Image script can used by providing commands to --apply-operations "<commands>", or by loading a script from a file using --operations-script.
Please refer to the --help page if you want to use operations from the CLI instead.

Image operations are always applied from left-to-right.

Image script commands:
----------------------

|-------------------|-----------------------------------|
| operations        | syntax*                           |
|-------------------|-----------------------------------|
|blur               | `blur <uint>`                     |
|brighten           | `brighten <int>`                  |
|crop               | `crop <uint> <uint> <uint> <uint>`|
|diff               | `diff <path>`                     |
|draw-text          | `draw-text <string> <nv:coord>    |
|                   |    <nv:rgba> <nv:size> <nv:font>` |
|filter3x3          | `filter3x3 <fp9x>`                |
|flip horizontal    | `flip-horizontal`                 |
|flip vertical      | `flip-vertical`                   |
|gray scale         | `grayscale`                       |
|horizontal gradient| `horizontal-gradient <nv:rgba>    |
|                   |    <nv:rgba>`                     |
|hue rotate         | `hue-rotate <int>`                |
|invert             | `invert`                          |
|overlay            | `overlay <path> <uint> <uint>`    |
|resize             | `resize <uint> <uint>`            |
|rotate90           | `rotate90`                        |
|rotate180          | `rotate180`                       |
|rotate270          | `rotate270`                       |
|unsharpen          | `unsharpen <fp> <int>`            |
|vertical gradient  | `vertical-gradient <nv:rgba>      |
|                   |    <nv:rgba>`                     |
|-------------------|-----------------------------------|

Legend:

<byte>: positive number in range 0-255
<uint>: positive number
<int>: positive or negative number
<fp>:  a real number
<fp9x>: 9 succeeding real numbers
<path>: a path to an image reachable from your current working directory (surround the path by "quotation marks")
<string>: a valid unicode string

<nv:coord>: a coordinate (top left is (0, 0)), with syntax: `coord(<uint>, <uint>)`
<nv:rgba>: an RGBA color, with syntax: `rgba(<byte>, <byte>, <byte>, <byte>) `
<nv:size>: a font size, with syntax: `size(<fp>)`
<nv:font>: a font file location, with syntax: `font(<path>)`

**modifiers**

Some image operations have extra options, called modifiers, which may change the behaviour of an operation.

Script mode allows you to set a modifier using the following syntax `set <modifier for operation> [<arg> 0..n]`.
The modifier settings can be overwritten by using the `set` command again, and can also be reset to their default value by
using the `del` command. The syntax for the `del` command is as follows: `del <image operation> <modifier for operation>`.

The available image operation modifiers are:

|===================|===========================================|
| for operation:    | modifier:                                 |
|===================|===========================================|
| resize            | preserve-aspect-ratio <bool>              |
| resize            | sampling-filter <filter>                  |
-----------------------------------------------------------------


|===================|===========================================|
| values:           | choices:                                  |
|===================|===========================================|
| <bool>            | true, false                               |
| <filter>          | catmullrom, gaussian,                     |
|                   | lanczos3 (default), nearest,              |
|                   | triangle                                  |
-----------------------------------------------------------------

Examples: image script
----------------------

Example 1: sic --input input.png --output output.png --apply-operations "invert; hue-rotate -75; rotate90; contrast 0.25"
Example 2: sic -i input.png -o output.png --apply-operations "set preserve-aspect-ratio true; set sampling-filter lanczos3; resize 250 250;"
Example 3: sic -i in.png -o out.png --apply-operations "rotate180; flip-horizontal; set sampling-filter nearest; resize 75 80; huerotate 75"
Example 4: sic -i in.png -o out.png --apply-operations "draw-text \'we can draw text <3\' coord(10, 10) rgba(200, 10, 40, 255) size(14) font(\'resources/font/Lato-Regular.ttf\')"


Examples: cli ops mode
----------------------

If we modify the above examples to use the cli instead, we will get the following:

Example 1: sic --input input.png --output output.png --invert --hue-rotate -75 --rotate90 --contrast 0.25
Example 2: sic -i input.png -o output.png --preserve-aspect-ratio true --sampling-filter lanczos3 --resize 250 250
Example 3: sic -i in.png -o out.png --rotate180 --flip-horizontal --sampling-filter nearest --resize 75 80 --hue-rotate 75"
Example 3: sic -i in.png -o out.png --draw-text "we can draw text <3" "coord(10, 10)" "rgba(200, 10, 40, 255)" "size(14)" "font(\'Lato-Regular.ttf\')"


---
'
complete -c sic -n "__fish_use_subcommand" -l operations-script -d 'Like \'--apply-operations\' but takes a file path where the file contains the script instead of taking it as value directly'
complete -c sic -n "__fish_use_subcommand" -l blur -d 'Operation: perform a gaussian blur on the input image'
complete -c sic -n "__fish_use_subcommand" -l brighten -d 'Operation: increase or decrease the brightness of the input image'
complete -c sic -n "__fish_use_subcommand" -l contrast -d 'Operation: increase or decrease the contrast of the input image'
complete -c sic -n "__fish_use_subcommand" -l crop -d 'Operation: crop the input image to a bounding rectangle ranging from top-left (lx, ly) to bottom-right (rx, ry) coordinates'
complete -c sic -n "__fish_use_subcommand" -l diff -d 'Operation: show '
complete -c sic -n "__fish_use_subcommand" -l filter3x3 -d 'Operation: apply a 3x3 convolution filter to the input image (matrix arguments should be given left-to-right, top-to-bottom)'
complete -c sic -n "__fish_use_subcommand" -l hue-rotate -d 'Operation: rotate the hue for each pixel of the input image by a provided degree'
complete -c sic -n "__fish_use_subcommand" -l horizontal-gradient -d 'Operation: blend the image with a horizontal gradient from color1 to color2.'
complete -c sic -n "__fish_use_subcommand" -l overlay -d 'Operation: overlay an image loaded from the provided path argument, over the input image (at a certain position)'
complete -c sic -n "__fish_use_subcommand" -l resize -d 'Operation: resize the input image to x by y pixels'
complete -c sic -n "__fish_use_subcommand" -l unsharpen -d 'Operation: sharpen an image by combining an unsharp (blurred) mask of the input image with the (original) input image, sharpening for pixels where the difference is bigger than the provided threshold'
complete -c sic -n "__fish_use_subcommand" -l vertical-gradient -d 'Operation: blend the image with a vertical gradient from color1 to color2.'
complete -c sic -n "__fish_use_subcommand" -l preserve-aspect-ratio -d 'Operation modifier for \'resize\': preserve the aspect ratio of the original input image' -r -f -a "true false"
complete -c sic -n "__fish_use_subcommand" -l sampling-filter -d 'Operation modifier for \'resize\': resize the image using a specific sampling-filter' -r -f -a "catmullrom gaussian lanczos3 nearest triangle"
complete -c sic -n "__fish_use_subcommand" -l draw-text -d 'Operation: draw-text.'
complete -c sic -n "__fish_use_subcommand" -l license -d 'Displays the license of this piece of software (`sic`).'
complete -c sic -n "__fish_use_subcommand" -l dep-licenses -d 'Displays the licenses of the dependencies on which this software relies.'
complete -c sic -n "__fish_use_subcommand" -l no-skip-unsupported-extensions -d 'Files which don\'t have a known extension will not be skipped in glob mode'
complete -c sic -n "__fish_use_subcommand" -l disable-automatic-color-type-adjustment -d 'Some image output formats do not support the color type of the image buffer prior to encoding. By default the program tries to adjust the color type. If this flag is provided, the program will not try to adjust the color type.'
complete -c sic -n "__fish_use_subcommand" -l pnm-encoding-ascii -d 'Use ascii based encoding when using a PNM image output format (pbm, pgm or ppm). Doesn\'t apply to \'pam\' (PNM Arbitrary Map).'
complete -c sic -n "__fish_use_subcommand" -l enable-output-format-decider-fallback -d '[experimental] When this flag is set, sic will attempt to fallback to an alternative output format decider (image crate version), *if* sic\'s own decider can\'t find a suitable format. Setting this flag may introduce unwanted behaviour; use with caution.'
complete -c sic -n "__fish_use_subcommand" -l flip-horizontal -d 'Operation: flip the input image horizontally'
complete -c sic -n "__fish_use_subcommand" -l flip-vertical -d 'Operation: flip the input image vertically'
complete -c sic -n "__fish_use_subcommand" -l grayscale -d 'Operation: discard the chrominance signal from the input image, so it becomes achromatic'
complete -c sic -n "__fish_use_subcommand" -l invert -d 'Operation: invert the each pixel of the input image '
complete -c sic -n "__fish_use_subcommand" -l rotate90 -d 'Operation: rotate the input image by 90 degrees'
complete -c sic -n "__fish_use_subcommand" -l rotate180 -d 'Operation: rotate the input image by 180 degrees'
complete -c sic -n "__fish_use_subcommand" -l rotate270 -d 'Operation: rotate the input image by 270 degrees'
complete -c sic -n "__fish_use_subcommand" -l threshold -d 'Operation: Threshold the input image using Otsu\'s method'
complete -c sic -n "__fish_use_subcommand" -s h -l help -d 'Prints help information'
complete -c sic -n "__fish_use_subcommand" -s V -l version -d 'Prints version information'
